@@ -1,6 +1,8 @@
 from plone.theme.interfaces import IDefaultPloneLayer
 from zope.viewlet.interfaces import IViewletManager
 from zope.interface import implements, Interface
+from plone.portlets.interfaces import IPortletManager
+
 
 class IIntkBaseLayer(IDefaultPloneLayer):
     """Marker interface that defines a Zope 3 browser layer.
@@ -42,4 +44,8 @@ class ISearchView(Interface):
 
     def createSearchURL(self, request, type):
 	"""Creates a search URL for the type
-	"""
\ No newline at end of file
+	"""
+        
+class IFooterPortlet(IPortletManager):
+    """we need our own portlet manager for the footer.
+    """
